/*******************************************************************************
 * Copyright (c) 2010 s IT Solutions AT Spardat GmbH .
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     s IT Solutions AT Spardat GmbH - initial API and implementation
 *******************************************************************************/
package org.openxma.dsl.pom.resource;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.xtext.naming.IQualifiedNameProvider;
import org.openxma.dsl.core.model.StatusFlag;
import org.openxma.dsl.core.resource.CoreDslResourceDescription;
import org.openxma.dsl.pom.model.Command;
import org.openxma.dsl.pom.model.Component;
import org.openxma.dsl.pom.model.DataObjectVariable;
import org.openxma.dsl.pom.model.GuiElement;
import org.openxma.dsl.pom.model.ObjectProperty;
import org.openxma.dsl.pom.model.ReferencedXMAPage;
import org.openxma.dsl.pom.model.XmadslPage;
import org.openxma.dsl.pom.util.PomSwitch;

import com.google.common.base.Predicate;

public class PomDslResourceDescription extends CoreDslResourceDescription {
    private static final Predicate<EObject> EXPORTED_OBJECTS_FILTER = new ExportedObjectsFilter();

    public PomDslResourceDescription(Resource resource, IQualifiedNameProvider nameProvider) {
        super(resource, nameProvider);
    }

    @Override
    protected Predicate<EObject> getExportedObjectsFilter() {
        return EXPORTED_OBJECTS_FILTER;
    }

    private static class ExportedObjectsFilter extends PomSwitch<Boolean> implements Predicate<EObject> {

        public boolean apply(EObject input) {
            return doSwitch(input);
        }

        @Override
        public Boolean defaultCase(EObject object) {
            return !(object instanceof StatusFlag);
        }

        @Override
        public Boolean caseGuiElement(GuiElement object) {
            return false;
        }

        @Override
        public Boolean caseComponent(Component object) {
            return true;
        }

        @Override
        public Boolean caseXmadslPage(XmadslPage object) {
            return true;
        }

        @Override
        public Boolean caseReferencedXMAPage(ReferencedXMAPage object) {
            return true;
        }

        @Override
        public Boolean caseCommand(Command object) {
            return false;
        }

        @Override
        public Boolean caseDataObjectVariable(DataObjectVariable object) {
            return false;
        }

        @Override
        public Boolean caseObjectProperty(ObjectProperty object) {
            return false;
        }

    }
}
